@@ -5,18 +5,20 @@ import subprocess
 def exist():
     sys = platform.system()
     if sys=="Darwin":
-        kexts = os.listdir("/Library/Extensions/")
+        kexts = "_".join(os.listdir("/Library/Extensions/"))
         return "usbserial.kext" in kexts
     elif sys=="Windows":
-        return False
+        return "ch341ser.inf" in "_".join(os.listdir("C:\Windows\System32\DriverStore\FileRepository"))
     return True
 
 def install():
+    if exist():
+        return True
     sys = platform.system()
     if sys=="Darwin":
         subprocess.call(["/usr/bin/open",os.path.dirname(__file__)+"/driver/ch34x_install.pkg"])
     elif sys=="Windows":
-        subprocess.call([os.path.dirname(__file__)+"/driver/ch34x_install.exe"])
+        subprocess.call([os.path.dirname(__file__)+"\driver\ch34x_install.exe","/sw","/se"])
     while not exist():
         sleep(1)
-    return
\ No newline at end of file
+    return True
\ No newline at end of file
